===========================
 API Reference
===========================

:Release: |version|
:Date: |today|

.. toctree::
    :maxdepth: 2

    kombu.connection
    kombu.simple
    kombu.messaging
    kombu.entity
    kombu.compat
    kombu.exceptions
    kombu.transport
    kombu.transport.pypika
    kombu.transport.pyamqplib
    kombu.transport.pyredis
    kombu.transport.memory
    kombu.transport.base
    kombu.transport.virtual
    kombu.serialization
    kombu.compression
    kombu.abstract
    kombu.utils
